==> apache-beam-2.5.0-source-release.zip: beam-release-2.5.0/sdks/go/pkg/beam/core/runtime/exec/multiplex.go <==
// Licensed to the Apache Software Foundation (ASF) under one or more
// contributor license agreements.  See the NOTICE file distributed with
// this work for additional information regarding copyright ownership.
// The ASF licenses this file to You under the Apache License, Version 2.0
// (the "License"); you may not use this file except in compliance with
// the License.  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package exec

import (
	"context"
	"fmt"
)

// Multiplex is a fan-out node. It simply forwards any call to all downstream nodes.
type Multiplex struct {
	// UID is the unit identifier.
	UID UnitID
	// Out is a list of output nodes.
	Out []Node
}

func (m *Multiplex) ID() UnitID {
	return m.UID
}

func (m *Multiplex) Up(ctx context.Context) error {
	return nil
}

func (m *Multiplex) StartBundle(ctx context.Context, id string, data DataManager) error {
	return MultiStartBundle(ctx, id, data, m.Out...)
}

func (m *Multiplex) ProcessElement(ctx context.Context, elm FullValue, values ...ReStream) error {
	for _, out := range m.Out {
		if err := out.ProcessElement(ctx, elm, values...); err != nil {
			return err
		}
	}
	return nil
}

func (m *Multiplex) FinishBundle(ctx context.Context) error {
	return MultiFinishBundle(ctx, m.Out...)
}

func (m *Multiplex) Down(ctx context.Context) error {
	return nil
}

func (m *Multiplex) String() string {
	return fmt.Sprintf("Multiplex. Out:%v", IDs(m.Out...))
}

==> apache-beam-2.7.0-source-release.zip: beam-release-2.7.0/sdks/go/pkg/beam/core/runtime/exec/multiplex.go <==
// Licensed to the Apache Software Foundation (ASF) under one or more
// contributor license agreements.  See the NOTICE file distributed with
// this work for additional information regarding copyright ownership.
// The ASF licenses this file to You under the Apache License, Version 2.0
// (the "License"); you may not use this file except in compliance with
// the License.  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package exec

import (
	"context"
	"fmt"
)

// Multiplex is a fan-out node. It simply forwards any call to all downstream nodes.
type Multiplex struct {
	// UID is the unit identifier.
	UID UnitID
	// Out is a list of output nodes.
	Out []Node
}

func (m *Multiplex) ID() UnitID {
	return m.UID
}

func (m *Multiplex) Up(ctx context.Context) error {
	return nil
}

func (m *Multiplex) StartBundle(ctx context.Context, id string, data DataContext) error {
	return MultiStartBundle(ctx, id, data, m.Out...)
}

func (m *Multiplex) ProcessElement(ctx context.Context, elm FullValue, values ...ReStream) error {
	for _, out := range m.Out {
		if err := out.ProcessElement(ctx, elm, values...); err != nil {
			return err
		}
	}
	return nil
}

func (m *Multiplex) FinishBundle(ctx context.Context) error {
	return MultiFinishBundle(ctx, m.Out...)
}

func (m *Multiplex) Down(ctx context.Context) error {
	return nil
}

func (m *Multiplex) String() string {
	return fmt.Sprintf("Multiplex. Out:%v", IDs(m.Out...))
}
